package com.zanxiang.common.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Objects;

/**
 * 支付方式枚举
 *
 * @author xufeng
 * @date 2022/6/9 10:41
 */
@Getter
@AllArgsConstructor
public enum PayWayEnum {

    /**
     * 支付宝
     */
    ALIPAY("AliPay", "支付宝", 1),

    /**
     * 微信支付
     */
    WXPAY("WxPay", "微信支付", 2),

    /**
     * 米大师支付
     */
    MIPAY("MiPay", "米大师支付", 3);

    /**
     * 支付方式
     */
    private final String code;

    /**
     * 支付名称
     */
    private final String name;

    /**
     * 序号
     */
    private final Integer num;

    /**
     * 根据书城key获取名称
     *
     * @param payType : 支付类型
     * @return : 支付类型枚举
     */
    public static String getByPayType(Long payType) {
        if (payType == null) {
            return null;
        }
        for (PayWayEnum payWayEnum : PayWayEnum.values()) {
            if (Objects.equals(payType.intValue(), payWayEnum.getNum())) {
                return payWayEnum.getName();
            }
        }
        return null;
    }

}
