package com.zanxiang.sdk.service.Impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zanxiang.common.enums.DeviceTypeEnum;
import com.zanxiang.mybatis.entity.User;
import com.zanxiang.mybatis.entity.UserLoginLog;
import com.zanxiang.mybatis.mapper.UserLoginLogMapper;
import com.zanxiang.sdk.domain.params.UserData;
import com.zanxiang.sdk.service.UserLoginLogService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

/**
 * @author : lingfeng
 * @time : 2022-06-13
 * @description : 用户登录日志
 */
@Slf4j
@Service
public class UserLoginLogServiceImpl extends ServiceImpl<UserLoginLogMapper, UserLoginLog> implements UserLoginLogService {

    /**
     * 创建角色登录日志
     *
     * @param userData 用户
     * @param type     类型
     * @param roleId   角色id
     * @return {@link Boolean}
     */
    @Override
    public Boolean createRoleLoginLog(UserData userData, String roleId, String roleName, Integer type) {
        //创建对象
        return super.save(UserLoginLog.builder()
                .userId(userData.getUserId())
                .gameId(userData.getGameId())
                .roleId(roleId)
                .roleName(roleName)
                .os(userData.getDeviceSystem())
                .ip(userData.getIp())
                .deviceType(DeviceTypeEnum.DEVICE_TYPE_ANDROID.getDeviceType())
                .type(type)
                .createTime(LocalDateTime.now())
                .build());
    }

    /**
     * 创建用户登录日志
     *
     * @param user 用户
     * @param type 类型
     * @return {@link Boolean}
     */
    @Override
    public Boolean createUserLoginLog(User user, Integer type) {
        return super.save(UserLoginLog.builder()
                .userId(user.getId())
                .gameId(user.getGameId())
                .os(user.getDeviceSystem())
                .ip(user.getIp())
                .deviceType(DeviceTypeEnum.DEVICE_TYPE_ANDROID.getDeviceType())
                .type(type)
                .createTime(LocalDateTime.now())
                .build());
    }
}
